@@ -133,7 +133,7 @@ This plugin provides the following :ref:`configurable warnings <configurable_war
 import os
 import errno
 import re
-from collections import Mapping
+from collections.abc import Mapping
 from io import StringIO
 
 from configparser import RawConfigParser
